; The **AB3DMT-3DScanning** model is created by [Donghua Chen](https://dhchenx.github.io).

; This is a NetLogo 3D model to demonstrate the scanning use of 3D point clouds from existing 3D models.
; This model is a part of our agent-based 3D modeling toolkit ([AB3DMT](https://github.com/dhchenx/AB3DMT)) platform
; that facilitates the use of 3D modeling in NetLogo 3D simulation.

; Author: Donghua Chen
; Date of model: 2022-08-03

extensions[
  csv
]

turtles-own[object-type]


globals[
  current
  min_x max_x
  min_y max_y
  min_z max_z
  total-points

]

__includes["AB3DMT-lib-3dmodel.nls"]


to setup
  ; clear world
  clear-all
  reset-ticks
  reset-timer
  set total-points 0
  set model-path "male.csv"
  set world-min-x -22
  set world-max-x 22
   set world-min-y -66
  set world-max-y 17
   set world-min-x -5
  set world-max-x 9
  set scale 10
  set point-size 1
  set world-scale 1.2
  set show-axis false
  set sample-rate 40

end

to load-model
  open-3d-model model-path true
end


to init-go
  reset-ticks
  clear-all-plots


  ask turtles with [object-type = "human"] [
    set color blue
  ]

  ask turtles with [object-type = "box"][die]

  clear-links

  clear-patches

end

to scan-y

  reset-ticks

  init-go

   scan-from-y world-min-x world-max-x world-min-y world-max-y world-min-z world-max-z scan-thick render-part? hide-cube?

end


to scan-x

  reset-ticks

  init-go

   scan-from-x world-min-x world-max-x world-min-y world-max-y world-min-z world-max-z scan-thick render-part? hide-cube?

end

to scan-z

  reset-ticks

  init-go

   scan-from-z world-min-x world-max-x world-min-y world-max-y world-min-z world-max-z scan-thick render-part? hide-cube?

end

to-report show-cube [x y z width height depth hide]

  ask turtles with [object-type =  "box"][
   die
  ]

  create-turtles 1 [
    setxyz x + width / 2 y  z
    facexyz x + width y  z
    set shape "line"
    set size width
    set color yellow
    set object-type "box"
    set hidden? hide
  ]

  create-turtles 1 [
    setxyz x y z

    set shape "dot"
    set size 2
    set color red
    set object-type "box"
    set hidden? hide
  ]

create-turtles 1 [
    setxyz x  y + height / 2 z
    facexyz x  y + height  z
    set shape "line"
    set size height
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

     create-turtles 1 [
    setxyz x + width  y + height / 2 z
    facexyz x + width  y + height  z
    set shape "line"
    set size height
    set color yellow
      set object-type "box"
    set hidden? hide
  ]


   create-turtles 1 [
    setxyz x + width / 2 y  z -  depth
    facexyz x + width y  z - depth
    set shape "line"
    set size width
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

    create-turtles 1 [
    setxyz x + width / 2 y + height  z -  depth
    facexyz x + width y + height  z - depth
    set shape "line"
    set size width
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

    create-turtles 1 [
    setxyz x  y + height / 2 z  -  depth
    facexyz x  y + height   z - depth
    set shape "line"
    set size height
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

    create-turtles 1 [
    setxyz x + width / 2 y + height  z
    facexyz x + width y + height z
    set shape "line"
    set size width
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

    create-turtles 1 [
    setxyz x + width   y + height / 2 z  -  depth
    facexyz x + width  y + height   z - depth
    set shape "line"
    set size height
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

        create-turtles 1 [
    setxyz x + width   y + height  z - depth / 2
    facexyz x + width  y + height   z - depth
    set shape "line"
    set size depth
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

   create-turtles 1 [
    setxyz x   y + height  z - depth / 2
    facexyz x  y + height   z - depth
    set shape "line"
    set size depth
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

       create-turtles 1 [
    setxyz x + width   y   z - depth / 2
    facexyz x + width  y   z - depth
    set shape "line"
    set size depth
    set color yellow
      set object-type "box"
    set hidden? hide
  ]

         create-turtles 1 [
    setxyz x   y   z - depth / 2
    facexyz x  y   z - depth
    set shape "line"
    set size depth
    set color yellow
      set object-type "box"
    set hidden? hide
  ]
  let result []
  set result (list (list x  (x + width))  (list y  (y + height)) (list (z - depth) z))

  report result

end

to-report is-in-cube [point corrs]


  let x item 0 point
  let y item 1 point
  let z item 2 point

  let xx item 0 corrs
  let yy item 1 corrs
  let zz item 2 corrs

  let x1 item 0 xx
  let x2 item 1 xx

  ifelse x >= x1 and x <= x2 and y >= item 0 yy and y <= item 1 yy and z >= item 0 zz and z <= item 1 zz
  [
    report true
  ][

      report false
  ]

end

to clear-all-cube
  ask turtles with [object-type = "box"][die]
end

to scan-from-y [my-world-min-x my-world-max-x my-world-min-y my-world-max-y my-world-min-z my-world-max-z my-scan-thick only-render-cube my-hide-cube]

   let cur-y my-world-min-y
  while [cur-y < my-world-max-y] [

    let r show-cube my-world-min-x cur-y my-world-max-z (my-world-max-x - my-world-min-x) scan-thick (my-world-max-z - my-world-min-z) my-hide-cube

     ask turtles with [object-type = "human"][
       ifelse only-render-cube =  true [
            ifelse is-in-cube (list xcor ycor zcor) r [

        set color red

    ][
          set color blue
      ]
      ]
      [
    if is-in-cube (list xcor ycor zcor) r [

        set color red

    ]
      ]


  ]
     set cur-y cur-y + my-scan-thick
     tick
  ]

  clear-all-cube



end


to scan-from-x [my-world-min-x my-world-max-x my-world-min-y my-world-max-y my-world-min-z my-world-max-z my-scan-thick only-render-cube my-hide-cube]

   let cur-x my-world-min-x
  while [cur-x < my-world-max-x] [

    let r show-cube cur-x my-world-min-y my-world-max-z  scan-thick (my-world-max-y - my-world-min-y) (my-world-max-z - my-world-min-z) my-hide-cube

     ask turtles with [object-type = "human"][
       ifelse only-render-cube =  true [
            ifelse is-in-cube (list xcor ycor zcor) r [

        set color red

    ][
          set color blue
      ]
      ]
      [
    if is-in-cube (list xcor ycor zcor) r [

        set color red

    ]
      ]


  ]
     set cur-x cur-x + my-scan-thick
    tick
  ]

  clear-all-cube



end

to scan-from-z [my-world-min-x my-world-max-x my-world-min-y my-world-max-y my-world-min-z my-world-max-z my-scan-thick only-render-cube my-hide-cube]

   let cur-z my-world-min-z
  while [cur-z < my-world-max-z] [

    let r show-cube my-world-min-x my-world-min-y cur-z (my-world-max-x - my-world-min-x) (my-world-max-y - my-world-min-y)  scan-thick  my-hide-cube

     ask turtles with [object-type = "human"][
       ifelse only-render-cube =  true [
            ifelse is-in-cube (list xcor ycor zcor) r [

        set color red

    ][
          set color blue
      ]
      ]
      [
    if is-in-cube (list xcor ycor zcor) r [

        set color red

    ]
      ]


  ]
     set cur-z cur-z + my-scan-thick
      tick
  ]

  clear-all-cube



end

@#$#@#$#@
GRAPHICS-WINDOW
0
0
593
1101
-1
-1
13.0
1
10
1
1
1
0
1
1
1
-22
22
-66
17
-5
9
1
0
1
ticks
30.0

BUTTON
121
163
217
196
NIL
load-model
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
30
49
424
117
model-path
male.csv
1
0
String

SWITCH
448
53
568
86
show-axis
show-axis
1
1
-1000

MONITOR
32
235
128
280
NIL
total-points
17
1
11

SLIDER
448
150
620
183
sample-rate
sample-rate
1
100
40.0
1
1
NIL
HORIZONTAL

SLIDER
448
102
620
135
scale
scale
0.1
10
10.0
1
1
NIL
HORIZONTAL

SLIDER
447
200
619
233
point-size
point-size
0
10
1.0
1
1
NIL
HORIZONTAL

SLIDER
683
53
855
86
world-min-x
world-min-x
-60
0
-22.0
1
1
NIL
HORIZONTAL

SLIDER
865
52
1037
85
world-max-x
world-max-x
0
60
22.0
1
1
NIL
HORIZONTAL

SLIDER
685
104
857
137
world-min-y
world-min-y
-60
0
-66.0
1
1
NIL
HORIZONTAL

SLIDER
866
104
1038
137
world-max-y
world-max-y
0
60
17.0
1
1
NIL
HORIZONTAL

SLIDER
683
150
855
183
world-min-z
world-min-z
-60
0
-5.0
1
1
NIL
HORIZONTAL

SLIDER
868
150
1040
183
world-max-z
world-max-z
0
60
9.0
1
1
NIL
HORIZONTAL

TEXTBOX
686
25
836
43
Adjust world size:
12
0.0
1

TEXTBOX
37
19
187
37
3D model path: 
12
0.0
1

TEXTBOX
40
136
190
154
Steps: 
12
0.0
1

TEXTBOX
450
22
600
40
Load settings: 
12
0.0
1

BUTTON
39
163
105
196
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
450
252
622
285
world-scale
world-scale
0
5
1.2
0.1
1
NIL
HORIZONTAL

BUTTON
253
166
326
199
NIL
scan-x
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
258
217
331
250
NIL
scan-y
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
259
264
332
297
NIL
scan-z
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
33
334
205
367
scan-thick
scan-thick
0
10
2.0
1
1
NIL
HORIZONTAL

SWITCH
222
335
363
368
render-part?
render-part?
1
1
-1000

SWITCH
375
335
502
368
hide-cube?
hide-cube?
1
1
-1000

TEXTBOX
31
305
181
323
Scanning settings: 
12
0.0
1

TEXTBOX
39
395
189
434
Author: Donghua Chen\nDate: 2022-08-03\nLicense: MIT
12
0.0
1

@#$#@#$#@
## WHAT IS IT?

The **AB3DMT-3DScanning** model is created by [Donghua Chen](https://dhchenx.github.io). 

This is a NetLogo 3D model to demonstrate the scanning use of 3D point clouds from existing 3D models. This model is a part of our agent-based 3D modeling toolkit ([AB3DMT](https://github.com/dhchenx/AB3DMT)) platform that facilitates the use of 3D modeling in NetLogo 3D simulation. 

Author: Donghua Chen
Date of model: 2022-08-03

## HOW IT WORKS

After we import a 3D point cloud model into NetLogo 3D using our [AB3DMT-3DModel model](http://modelingcommons.org/browse/one_model/7047#model_tabs_browse_info), we can design three directional scanning agent-based methods, namely scan-x, scan-y and scan-z. 

For example, the scan-x algoritm scans the 3D model from the lowest x value to largest x value along the axis. So are scan-y and scan-z algorithms. 

There are three scanning settings: 

- scan-thick: determine the length of scanning along the axis. 

- render-part?: determine whether we should keep the scanned points with visited colors in a new scanning position. 

- hide-cude?: determine whether the cube box should display during scanning. 

## HOW TO USE IT

When you want to use this model, first, download all necessary file including:

- AB3DMT-3DScanning.nlogo3d

- AB3DMT-lib-3dmodel.nls

- sample 3D file: male.csv

Three above files are put in the same folder. Then you need to run the .nlogo3d file to start simulation. 

Step 1: click SETUP button to initialize the model;

Step 2: clikc LOAD-MODEL button to load 3d points into NetLogo 3D. Then you should see a 3D model displaying in the NetLogo world; 

Step 3: After the model is loaded, you can click the buttons like scan-x, scan-y or scan-z to examine the function of this toolkit. 


## THINGS TO NOTICE

This model works in NetLogo 3D 6.2.1. 

## THINGS TO TRY

With the established agent-based 3D model in NetLogo 3D, you can perform various agent-based methods to simulate cases in the 3D context with great complexity. 

You may import other 3D models into NetLogo following the csv format by changing the default csv file in the NetLogo code. 

## EXTENDING THE MODEL

We are working on the development of high-level agent-based modeling platform in 3D environment, please refer to my GitHub project: https://github.com/dhchenx/AB3DMT. 

Please let us know if there is any problem in: https://github.com/dhchenx/AB3DMT/issues


## HOW TO CITE

The model's project page: https://github.com/dhchenx/AB3DMT

Please cite our GitHub project if the model is used in your research. 

Donghua Chen (2022). Agent-based 3D modeling toolkit (Version 0.0.7) [Source code]. https://github.com/dhchenx/AB3DMT. [2022-08-03]. 

## COPYRIGHT AND LICENSE

Copyright 2022 Donghua Chen

License: MIT


@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 3D 6.2.1
@#$#@#$#@
need-to-manually-make-preview-for-this-model
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
